@@ -1,5 +1,6 @@
 import datetime
 import functools
+import sys
 
 from dateutil import parser
 
@@ -8,7 +9,6 @@ real_datetime = datetime.datetime
 
 
 class FakeDate(real_date):
-    active = False
     date_to_freeze = None
 
     def __new__(cls, *args, **kwargs):
@@ -31,15 +31,11 @@ class FakeDate(real_date):
 
     @classmethod
     def today(cls):
-        if cls.active:
-            result = cls.date_to_freeze
-        else:
-            result = real_date.today()
+        result = cls.date_to_freeze
         return date_to_fakedate(result)
 
 
 class FakeDatetime(real_datetime, FakeDate):
-    active = False
     time_to_freeze = None
     tz_offset = None
 
@@ -63,23 +59,14 @@ class FakeDatetime(real_datetime, FakeDate):
 
     @classmethod
     def now(cls):
-        if cls.active:
-            result = cls.time_to_freeze + datetime.timedelta(hours=cls.tz_offset)
-        else:
-            result = real_datetime.now()
+        result = cls.time_to_freeze + datetime.timedelta(hours=cls.tz_offset)
         return datetime_to_fakedatetime(result)
 
     @classmethod
     def utcnow(cls):
-        if cls.active:
-            result = cls.time_to_freeze
-        else:
-            result = real_datetime.utcnow()
+        result = cls.time_to_freeze
         return result
 
-datetime.datetime = FakeDatetime
-datetime.date = FakeDate
-
 
 def datetime_to_fakedatetime(datetime):
     return FakeDatetime(datetime.year,
@@ -116,18 +103,40 @@ class _freeze_time():
         self.stop()
 
     def start(self):
+        datetime.datetime = FakeDatetime
+        datetime.date = FakeDate
+
+        modules_for_datetime_faking = []
+        modules_for_date_faking = []
+
+        modules = sys.modules.values()
+
+        for module in modules:
+            if module is None:
+                continue
+            if module.__name__ != 'datetime':
+                if hasattr(module, 'datetime') and module.datetime == real_datetime:
+                    module.datetime = FakeDatetime
+                if hasattr(module, 'date') and module.date == real_date:
+                    module.date = FakeDate
+
         datetime.datetime.time_to_freeze = self.time_to_freeze
         datetime.datetime.tz_offset = self.tz_offset
-        datetime.datetime.active = True
 
         # Since datetime.datetime has already been mocket, just use that for
         # calculating the date
         datetime.date.date_to_freeze = datetime.datetime.now().date()
-        datetime.date.active = True
 
     def stop(self):
-        datetime.datetime.active = False
-        datetime.date.active = False
+        datetime.datetime = real_datetime
+        datetime.date = real_date
+
+        for mod_name, module in sys.modules.items():
+            if mod_name != 'datetime':
+                if hasattr(module, 'datetime') and module.datetime == FakeDatetime:
+                    module.datetime = real_datetime
+                if hasattr(module, 'date') and module.date == FakeDate:
+                    module.date = real_date
 
     def decorate_callable(self, func):
         def wrapper(*args, **kwargs):
